declare type Maybe<T> = T | null;
export declare type WebhookAttributes = WebhookCollectionsCreateAttributes | WebhookCollectionsUpdateAttributes | WebhookCollectionsDeleteAttributes | WebhookProductsCreateAttributes | WebhookProductsUpdateAttributes | WebhookProductsDeleteAttributes | WebhookOrdersCreateAttributes | WebhookOrdersUpdatedAttributes | WebhookMarketsCreateAttributes | WebhookMarketsUpdateAttributes | WebhookMarketsDeleteAttributes;
interface WebhookAttributesBase {
    "X-Shopify-Topic": string;
    "X-Shopify-Webhook-Id": string;
    "X-Shopify-API-Version": string;
    "X-Shopify-Hmac-SHA256": string;
    "X-Shopify-Shop-Domain": string;
    "Content-Type": "application/json";
}
export interface WebhookCollectionsCreateAttributes extends WebhookAttributesBase {
    /**
     * Integer ID, like "285352591544"
     */
    "X-Shopify-Collection-Id": string;
    "X-Shopify-Topic": "collections/create";
}
export interface WebhookCollectionsUpdateAttributes extends WebhookAttributesBase {
    /**
     * Integer ID, like "285352591544"
     */
    "X-Shopify-Collection-Id": string;
    "X-Shopify-Topic": "collections/update";
}
export interface WebhookCollectionsDeleteAttributes extends WebhookAttributesBase {
    /**
     * Integer ID, like "285352591544"
     */
    "X-Shopify-Collection-Id": string;
    "X-Shopify-Topic": "collections/delete";
}
export interface WebhookProductsCreateAttributes extends WebhookAttributesBase {
    /**
     * Integer ID, like "285352591544"
     */
    "X-Shopify-Product-Id": string;
    "X-Shopify-Topic": "products/create";
}
export interface WebhookProductsUpdateAttributes extends WebhookAttributesBase {
    /**
     * Integer ID, like "285352591544"
     */
    "X-Shopify-Product-Id": string;
    "X-Shopify-Topic": "products/update";
}
export interface WebhookProductsDeleteAttributes extends WebhookAttributesBase {
    /**
     * Integer ID, like "285352591544"
     */
    "X-Shopify-Product-Id": string;
    "X-Shopify-Topic": "products/delete";
}
export interface WebhookOrdersCreateAttributes extends WebhookAttributesBase {
    /**
     * Integer ID, like "285352591544"
     */
    "X-Shopify-Order-Id": string;
    "X-Shopify-Topic": "orders/create";
}
export interface WebhookOrdersUpdatedAttributes extends WebhookAttributesBase {
    /**
     * Integer ID, like "285352591544"
     */
    "X-Shopify-Order-Id": string;
    "X-Shopify-Topic": "orders/updated";
}
export interface WebhookMarketsCreateAttributes extends WebhookAttributesBase {
    /**
     * Integer ID, like "285352591544"
     */
    "X-Shopify-Product-Id": string;
    "X-Shopify-Topic": "markets/create";
}
export interface WebhookMarketsUpdateAttributes extends WebhookAttributesBase {
    /**
     * Integer ID, like "285352591544"
     */
    "X-Shopify-Product-Id": string;
    "X-Shopify-Topic": "markets/update";
}
export interface WebhookMarketsDeleteAttributes extends WebhookAttributesBase {
    /**
     * Integer ID, like "285352591544"
     */
    "X-Shopify-Product-Id": string;
    "X-Shopify-Topic": "markets/delete";
}
export interface WebhookCollectionPayload {
    id: number;
    handle: string;
    title: string;
    updated_at: string;
    body_html: string;
    published_at: string;
    sort_order: string;
    template_suffix: string;
    disjunctive: boolean;
    rules: {
        column: string;
        relation: string;
        condition: string;
    }[];
    published_scope: string;
    admin_graphql_api_id: string;
    metafields?: Array<WebhookMetafieldPayload>;
}
export interface WebhookProductPayload {
    id: number;
    title: string;
    body_html: string;
    vendor: string;
    product_type: string;
    created_at: string;
    handle: string;
    updated_at: string;
    published_at: string;
    template_suffix: string;
    status: string;
    published_scope: string;
    tags: string;
    admin_graphql_api_id: string;
    variants: {
        id: number;
        product_id: number;
        title: string;
        display_name: Maybe<string>;
        price: string;
        sku: string;
        position: number;
        inventory_policy: string;
        compare_at_price: Maybe<string>;
        fulfillment_service: string;
        inventory_management: string;
        option1: Maybe<string>;
        option2: Maybe<string>;
        option3: Maybe<string>;
        created_at: string;
        updated_at: string;
        taxable: boolean;
        barcode: string;
        grams: number;
        image_id: Maybe<number>;
        weight: number;
        weight_unit: string;
        inventory_item_id: number;
        inventory_quantity: number;
        old_inventory_quantity: number;
        requires_shipping: boolean;
        admin_graphql_api_id: string;
    }[];
    options: {
        id: number;
        product_id: number;
        name: string;
        position: number;
        values: string[];
    }[];
    images: WebhookProductImagePayload[];
    image: Maybe<WebhookProductImagePayload>;
    metafields?: Array<WebhookMetafieldPayload>;
}
export interface WebhookProductImagePayload {
    id: number;
    product_id: number;
    position: number;
    created_at: string;
    updated_at: string;
    alt: Maybe<string>;
    width: number;
    height: number;
    src: string;
    variant_ids: number[];
    admin_graphql_api_id: string;
}
export interface WebhookMetafieldPayload {
    id: number;
    namespace: string;
    key: string;
    value: string;
    value_type: string;
    description: Maybe<string>;
    owner_id: number;
    created_at: string;
    updated_at: string;
    owner_resource: string;
    type: string;
    admin_graphql_api_id: string;
}
export interface WebhookMoneyBagPayload {
    shop_money: WebhookMoneyInputPayload;
    presentment_money: WebhookMoneyInputPayload;
}
export interface WebhookMoneyInputPayload {
    amount: string;
    currency_code: string;
}
export declare enum WebhookOrderFinancialStatusPayload {
    Authorized = "AUTHORIZED",
    Expired = "EXPIRED",
    Paid = "PAID",
    PartiallyPaid = "PARTIALLY_PAID",
    PartiallyRefunded = "PARTIALLY_REFUNDED",
    Pending = "PENDING",
    Refunded = "REFUNDED",
    Voided = "VOIDED"
}
export declare enum WebhookOrderFulfillmentStatusPayload {
    Fulfilled = "FULFILLED",
    InProgress = "IN_PROGRESS",
    OnHold = "ON_HOLD",
    Open = "OPEN",
    PartiallyFulfilled = "PARTIALLY_FULFILLED",
    PendingFulfillment = "PENDING_FULFILLMENT",
    Restocked = "RESTOCKED",
    Scheduled = "SCHEDULED",
    Unfulfilled = "UNFULFILLED"
}
export interface WebhookOrderPayload {
    admin_graphql_api_id: string;
    created_at: string;
    id: number;
    financial_status: WebhookOrderFinancialStatusPayload;
    fulfillment_status: WebhookOrderFulfillmentStatusPayload;
    total_price_set: WebhookMoneyBagPayload;
    line_items: {
        price: string;
        product_id: number;
        quantity: number;
        sku: string;
        variant_id: number;
        name: string;
        price_set: WebhookMoneyBagPayload;
        properties: {
            name: string;
            value: string;
        }[];
        tax_lines: {
            title: string;
            price: string;
            rate: number;
        }[];
        total_discount_set: WebhookMoneyBagPayload;
        discount_allocations: {
            amount: string;
            discount_application_index: number;
            amount_set: WebhookMoneyBagPayload;
        }[];
    }[];
    name: string;
    number: number;
    order_number: number;
    tags: string;
    tax_lines: {
        price: number;
        rate: number;
        title: string;
        channel_liable: boolean;
    }[];
    updated_at: string;
}
export interface WebhookMarketPayload {
    id: number;
    name: string;
    enabled: boolean;
    regions: Array<{
        country_code: string;
    }>;
}
export {};
